@@ -8,15 +8,13 @@ password = '1163443a265e4b27cc69b8e55ed179af7e'
 
 job_name = 'job/truemoney-batch-common/job/truemoney-batch-common-truemoney-poi-settlement-qa-run-pipeline'
 
-
-
-jenkins = JenkinsFace(protocol, url, username, password)
+jenkins = JenkinsFace()
+jenkins.create_session_jenkins(protocol, url, username, password)
 
 # GET JOB DETAUL
-job_detail = jenkins.get_job(job_name)
+job_detail = jenkins.get_jenkins_job(job_name)
 print(job_detail['nextBuildNumber'])
 
-
 # BUILD JOB WITH PARAMS
 # req = {
 # 	"JavaOptions": "-XX:MaxMetaspaceSize=128m -Xss1m",
@@ -31,4 +29,4 @@ print(job_detail['nextBuildNumber'])
 # print(job_detail['building'])
 
 # job_detail = jenkins.get_job_build(job_name, build_number=18)
-# print(job_detail['building'])
\ No newline at end of file
+# print(job_detail['building'])
